#ifndef NT2_INCLUDE_CONSTANTS_FACT_7_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_FACT_7_HPP_INCLUDED

#include <nt2/constant/include/constants/fact_7.hpp>

#endif
